.. _Configuration_details:

#######################
Idl Configuration
#######################


This section should include information pertinent to the CSC configuration.
Items include: where the configuration files are located, which values in the file are most likely to be modified, a link to the schema.
Also verify that the descriptions in the schema are sufficient to explain the appropriate values

Some subsystems also have more complex configuration files (e.g. binaries).
Explanations of these files should be included, as well as a pointer to how they were created and what other artifacts may exist.
